@@ -1,6 +1,5 @@
+import { Logo, Wordmark } from 'mrpj/lib/logo';
 import { awscdk, release, github } from 'projen';
-import { LogoSystem } from './projenrc/LogoSystem';
-import { WorkflowNoDockerPatch } from './projenrc/WorkflowNoDockerPatch';
 
 const project = new awscdk.AwsCdkConstructLibrary({
   projenrcTs: true,
@@ -44,8 +43,7 @@ const project = new awscdk.AwsCdkConstructLibrary({
     'aws-cdk@^2.42.0',
     'aws-cdk-lib@^2.42.0',
     'constructs@^10.0.5',
-    'lodash.merge',
-    '@types/lodash.merge',
+    'mrpj',
   ],
   peerDependencyOptions: {
     pinnedDevDependency: false,
@@ -57,42 +55,29 @@ const project = new awscdk.AwsCdkConstructLibrary({
 });
 
 // Logos
-new LogoSystem(project, {
-  dirName: 'images',
-  logo: {
-    width: 145,
-    height: 166,
-    scale: 1.23,
+const logo = Logo.fromFile('images/logo.svg', {
+  width: 145,
+  height: 166,
+});
+logo.synth(project);
+new Wordmark(project, {
+  logo,
+  logoScale: 1.23,
+  logoPosition: {
     dx: 3,
   },
-  wordmark: {
-    font: {
-      color: '#6F7174',
-    },
-    colorScheme: {
-      dark: {
-        color: '#f0f6fc',
-      },
-      light: {
-        color: '#191919',
-      },
-    },
-    size: {
-      scale: 0.5,
-    },
-    raw: `<text y="100">
+  size: {
+    scale: 0.5,
+  },
+  raw: `<text y="100">
     <tspan x="210" dy="0em" font-size="80px">streamlink</tspan>
     <tspan x="210" dy="1em" font-size="50px">serverless</tspan>
 </text>`,
-  },
 });
 
 // Ignore cdk directories
 project.addPackageIgnore('cdk.out');
 
-// Fix Docker on GitHub
-new WorkflowNoDockerPatch(project, { workflow: 'build' });
-new WorkflowNoDockerPatch(project, { workflow: 'release' });
 
 // jsii rosetta
 project.package.addField('jsiiRosetta', {
